@@ -73,7 +73,7 @@ typedef struct {
 	GtkWidget *current_value_label;
 	GtkWidget *solution_label;
 	GtkWidget *result_label;
-	GtkWidget *result_table;
+	GtkWidget *result_grid;
 	Sheet	  *sheet;
 	Workbook  *wb;
 	WBCGtk  *wbcg;
@@ -273,7 +273,7 @@ cb_dialog_destroy (GoalSeekState *state)
 
 	value_release (state->old_value);
 	if (state->gui != NULL)
-		g_object_unref (G_OBJECT (state->gui));
+		g_object_unref (state->gui);
 
 	wbcg_edit_finish (state->wbcg, WBC_EDIT_REJECT, NULL);
 	g_free (state);
@@ -456,7 +456,7 @@ cb_dialog_apply_clicked (G_GNUC_UNUSED GtkWidget *button,
 	}
 	state->cancelled = FALSE;
 
-	gtk_widget_show (state->result_table);
+	gtk_widget_show (state->result_grid);
 	return;
 }
 
@@ -472,7 +472,7 @@ static void
 dialog_realized (G_GNUC_UNUSED GtkWidget *dialog,
 		 GoalSeekState *state)
 {
-	gtk_widget_hide (state->result_table);
+	gtk_widget_hide (state->result_grid);
 }
 
 /**
@@ -505,12 +505,16 @@ dialog_preload_selection (GoalSeekState *state, GnmExprEntry *entry)
 static gboolean
 dialog_init (GoalSeekState *state)
 {
-	GtkTable *table;
+	GtkGrid *grid;
 
 	state->dialog = go_gtk_builder_get_widget (state->gui, "GoalSeek");
         if (state->dialog == NULL)
                 return TRUE;
 
+	gnm_dialog_setup_destroy_handlers (GTK_DIALOG (state->dialog),
+					   state->wbcg,
+					   GNM_DIALOG_DESTROY_CURRENT_SHEET_REMOVED);
+
 	state->close_button     = go_gtk_builder_get_widget (state->gui, "closebutton");
 	g_signal_connect (G_OBJECT (state->close_button),
 		"clicked",
@@ -540,18 +544,17 @@ dialog_init (GoalSeekState *state)
 	gtk_label_set_justify (GTK_LABEL (state->solution_label), GTK_JUSTIFY_RIGHT);
 
 	state->result_label = go_gtk_builder_get_widget (state->gui, "result-label");
-	state->result_table = go_gtk_builder_get_widget (state->gui, "result-table");
+	state->result_grid = go_gtk_builder_get_widget (state->gui, "result-grid");
 
-	table = GTK_TABLE (go_gtk_builder_get_widget (state->gui, "goal-table"));
+	grid = GTK_GRID (go_gtk_builder_get_widget (state->gui, "goal-grid"));
 	state->set_cell_entry = gnm_expr_entry_new (state->wbcg, TRUE);
 	gnm_expr_entry_set_flags (state->set_cell_entry,
 				  GNM_EE_SINGLE_RANGE |
 				  GNM_EE_FORCE_ABS_REF,
 				  GNM_EE_MASK);
-	gtk_table_attach (table, GTK_WIDGET (state->set_cell_entry),
-			  2, 3, 1, 2,
-			  GTK_EXPAND | GTK_FILL, 0,
-			  0, 0);
+	gtk_grid_attach (grid, GTK_WIDGET (state->set_cell_entry),
+			  1, 0, 1, 1);
+	gtk_widget_set_hexpand (GTK_WIDGET (state->set_cell_entry), TRUE);
 	gnumeric_editable_enters (GTK_WINDOW (state->dialog),
 				  GTK_WIDGET (state->set_cell_entry));
 	dialog_preload_selection (state, state->set_cell_entry);
@@ -562,10 +565,9 @@ dialog_init (GoalSeekState *state)
 				  GNM_EE_SINGLE_RANGE |
 				  GNM_EE_FORCE_ABS_REF,
 				  GNM_EE_MASK);
-	gtk_table_attach (table, GTK_WIDGET (state->change_cell_entry),
-			  2, 3, 3, 4,
-			  GTK_EXPAND | GTK_FILL, 0,
-			  0, 0);
+	gtk_grid_attach (grid, GTK_WIDGET (state->change_cell_entry),
+			  1, 2, 1, 1);
+	gtk_widget_set_hexpand (GTK_WIDGET (state->change_cell_entry), TRUE);
 	gnumeric_editable_enters (GTK_WINDOW (state->dialog),
 				  GTK_WIDGET (state->change_cell_entry));
 	dialog_preload_selection (state, state->change_cell_entry);
