@@ -1183,6 +1183,8 @@ gnm_expr_range_op (GnmExpr const *expr, GnmEvalPos const *ep,
 	switch (GNM_EXPR_GET_OPER (expr)) {
 	case GNM_EXPR_OP_RANGE_CTOR:
 		res_range = range_union (&a_range, &b_range);
+		/* b_range might be on a bigger sheet.  */
+		range_ensure_sanity (&res_range, a_start);
 		break;
 	case GNM_EXPR_OP_INTERSECT:
 		/* 3D references not allowed.  */
