@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gnm-so-path.c
  *
@@ -118,14 +119,16 @@ so_path_view_set_bounds (SheetObjectView *sov, double const *coords, gboolean vi
 						y1 = My;
 				}
 			}
-			x1 += x0 + (sop->margin_pts.left - sop->margin_pts.right);
-			y1 += y0 + (sop->margin_pts.top - sop->margin_pts.bottom);
+			x1 -= x0 + sop->margin_pts.left + sop->margin_pts.right;
+			y1 -= y0 + sop->margin_pts.top + sop->margin_pts.bottom;
+			x0 += x1 / 2. + sop->margin_pts.left;
+			y0 += y1 / 2. + sop->margin_pts.top;
 			x1 = MAX (x1, DBL_MIN);
 			y1 = MAX (y1, DBL_MIN);
 
 			goc_item_set (GOC_ITEM (spv->text),
-			              "x", x1 / 2.,
-			              "y", y1 / 2.,
+			              "x", x0,
+			              "y", y0,
 				          "clip-height", y1,
 				          "clip-width",  x1,
 				          "wrap-width",  x1,
@@ -157,7 +160,8 @@ enum {
 	SOP_PROP_PATH,
 	SOP_PROP_TEXT,
 	SOP_PROP_MARKUP,
-	SOP_PROP_PATHS
+	SOP_PROP_PATHS,
+	SOP_PROP_VIEWBOX
 };
 
 
@@ -212,16 +216,39 @@ cb_gnm_so_path_changed (GnmSOPath const *sop,
 		GOStyle *style;
 		if (group->text == NULL) {
 			double x0, y0, x1, y1;
-			goc_item_get_bounds (group->path, &x0, &y0, &x1, &y1);
-			x1 += x0 + (sop->margin_pts.left - sop->margin_pts.right);
-			y1 += y0 + (sop->margin_pts.top - sop->margin_pts.bottom);
+			if (group->path)
+				goc_item_get_bounds (group->path, &x0, &y0, &x1, &y1);
+			else {
+				unsigned i;
+				double mx, my, Mx, My;
+				x0 = y0 = G_MAXDOUBLE;
+				x1 = y1 = -G_MAXDOUBLE;
+				for (i = 0; i < group->paths->len; i++) {
+					goc_item_get_bounds (GOC_ITEM (g_ptr_array_index (group->paths, i)), &mx, &my, &Mx, &My);
+					if (mx < x0)
+						x0 = mx;
+					if (my < y0)
+						y0 = my;
+					if (Mx > x1)
+						x1 = Mx;
+					if (My > y1)
+						y1 = My;
+				}
+			}
+			x1 -= x0 + sop->margin_pts.left + sop->margin_pts.right;
+			y1 -= y0 + sop->margin_pts.top + sop->margin_pts.bottom;
+			x0 += x1 / 2. + sop->margin_pts.left;
+			y0 += y1 / 2. + sop->margin_pts.top;
 			x1 = MAX (x1, DBL_MIN);
 			y1 = MAX (y1, DBL_MIN);
 			group->text = goc_item_new (GOC_GROUP (group), GOC_TYPE_TEXT,
 				"anchor",	GO_ANCHOR_CENTER,
 				"clip",		TRUE,
-				"x",		x1 / 2.,
-				"y",		y1 / 2.,
+				"x",		x0,
+				"y",		y0,
+		        "clip-height", y1,
+		        "clip-width",  x1,
+		        "wrap-width",  x1,
 				"attributes",	sop->markup,
 				NULL);
 		}
@@ -302,14 +329,16 @@ gnm_so_path_draw_cairo (SheetObject const *so, cairo_t *cr,
 	/* Draw the text. */
 	if (sop->text != NULL && *(sop->text) != '\0') {
 		PangoLayout *pl = pango_cairo_create_layout (cr);
-		double pl_height = (height - sop->margin_pts.top
-				    - sop->margin_pts.bottom) * PANGO_SCALE;
-		double pl_width = (width - sop->margin_pts.left
-				   - sop->margin_pts.right) * PANGO_SCALE;
-		/* set a font, a very bad solution, but will do until we move to GOString */
-		PangoFontDescription *desc = pango_font_description_from_string ("Sans 10");
 		double const scale_h = 72. / gnm_app_display_dpi_get (TRUE);
 		double const scale_v = 72. / gnm_app_display_dpi_get (FALSE);
+		double pl_height = (height - sop->margin_pts.top
+				    - sop->margin_pts.bottom) * PANGO_SCALE
+				    / scale_v;
+		double pl_width = (width - sop->margin_pts.left
+				   - sop->margin_pts.right) * PANGO_SCALE
+				   / scale_h;
+		/* set a font, a very bad solution, but will do until we move to GOString */
+		PangoFontDescription *desc = pango_font_description_from_string ("Sans 10");
 		PangoRectangle r;
 		pango_layout_set_font_description (pl, desc);
 		pango_layout_set_text (pl, sop->text, -1);
@@ -332,7 +361,7 @@ gnm_so_path_draw_cairo (SheetObject const *so, cairo_t *cr,
 
 static void
 gnm_so_path_write_xml_sax (SheetObject const *so, GsfXMLOut *output,
-			     GnmConventions const *convs)
+			   G_GNUC_UNUSED GnmConventions const *convs)
 {
 	GnmSOPath const *sop = GNM_SO_PATH (so);
 	char *svg;
@@ -399,7 +428,7 @@ sop_sax_style (GsfXMLIn *xin, xmlChar const **attrs)
 static void
 gnm_so_path_prep_sax_parser (SheetObject *so, GsfXMLIn *xin,
 			       xmlChar const **attrs,
-			       GnmConventions const *convs)
+			       G_GNUC_UNUSED GnmConventions const *convs)
 {
 	static GsfXMLInNode const dtd[] = {
 	  GSF_XML_IN_NODE (SOPATH, SOPATH, -1, "SheetObjectPath",	GSF_XML_NO_CONTENT, NULL, NULL),
@@ -548,6 +577,8 @@ gnm_so_path_set_property (GObject *obj, guint param_id,
 			pango_attr_list_ref (sop->markup);
 		break;
 
+	case SOP_PROP_VIEWBOX:
+		/* not settable */
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		return;
@@ -575,6 +606,12 @@ gnm_so_path_get_property (GObject *obj, guint param_id,
 	case SOP_PROP_MARKUP :
 		g_value_set_boxed (value, sop->markup);
 		break;
+	case SOP_PROP_VIEWBOX :
+		g_value_take_string 
+			(value, 
+			 g_strdup_printf ("%0.0f %0.0f %0.0f %0.0f", sop->x_offset, sop->y_offset, 
+					  sop->width + sop->x_offset, sop->height + sop->y_offset));
+		break;		
 	default :
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		break;
@@ -641,6 +678,9 @@ gnm_so_path_class_init (GObjectClass *gobject_class)
     g_object_class_install_property (gobject_class, SOP_PROP_PATHS,
              g_param_spec_boxed ("paths", NULL, NULL, G_TYPE_PTR_ARRAY,
 		GSF_PARAM_STATIC | G_PARAM_READWRITE));
+    g_object_class_install_property (gobject_class, SOP_PROP_VIEWBOX,
+             g_param_spec_string ("viewbox", NULL, NULL, NULL,
+		GSF_PARAM_STATIC | G_PARAM_READABLE));
 }
 
 static void
